#include "Game.h"



Game::Game(SDL_Window* window, RendererGL* rendererGL) {
    //Run the game.
    if (window != nullptr && rendererGL != nullptr) {
        //Store the current times for the clock.
        auto time1 = std::chrono::system_clock::now();
        auto time2 = std::chrono::system_clock::now();


        //Start the game loop and run until it's time to stop.
        bool running = true;
        while (running) {
            //Determine how much time has elapsed since the last frame.
            time2 = std::chrono::system_clock::now();
            std::chrono::duration<float> timeDelta = time2 - time1;
            float timeDeltaFloat = timeDelta.count();

            //Store the new time for the next frame.
            time1 = time2;

            //The amount of time for each frame (no longer than 20 fps).
            const float dT = std::min(timeDeltaFloat, 1.0f / 20.0f);

            processEvents(running);
            draw(window, rendererGL);
        }
    }
}


Game::~Game() {
    //Clean up.
}



void Game::processEvents(bool& running) {
	//Process events.
	SDL_Event event;
	while (SDL_PollEvent(&event)) {
		switch (event.type) {
		case SDL_QUIT:
			running = false;
			break;

		case SDL_KEYDOWN:
			switch (event.key.keysym.scancode) {
				//Quit the game.
			case SDL_SCANCODE_ESCAPE:
				running = false;
				break;
			}
		}
	}
}



void Game::draw(SDL_Window* window, RendererGL* rendererGL) {
	if (rendererGL != nullptr) {
		//Draw.
		//Set the background color.
		glClearColor(0.0f, 0.25f, 0.75f, 1.0f);
		//Clear the screen.
		glClear(GL_COLOR_BUFFER_BIT);


		//Draw Shapes
		SDL_Rect rect = { 50, 80, 150, 80 };
		rendererGL->setDrawColor(213, 116, 0, 255);
		rendererGL->fillOval(&rect);

		rect = { 110, 260, 110, 130 };
		rendererGL->setDrawColor(255, 255, 0, 255);
		rendererGL->fillRect(&rect);

		rect = { 320, 125, 150, 200 };
		rendererGL->setDrawColor(190, 74, 194, 255);
		rendererGL->fillOval(&rect);

		rect = { 610, 60, 150, 180 };
		rendererGL->setDrawColor(0, 224, 74, 255);
		rendererGL->fillRect(&rect);

		rect = { 590, 330, 240, 135 };
		rendererGL->setDrawColor(255, 0, 0, 255);
		rendererGL->fillOval(&rect);


		//Send the image to the window.
		rendererGL->swapWindow();
	}
}